/**
 * En klass som beskriver en Bok.
 */
public class Bok implements Comparable<Bok>
{
    private String skribent;
    private String titel;
    private int bredd;

    /**
     * Skapar en ny Bok.
     * @param skribent Bokens författare.
     * @param titel    Bokens titel.
     * @param bredd    Bokens bredd.
     */
    public Bok(String skribent, String titel, int bredd)
    {
        this.skribent = skribent;
        this.titel = titel;
        this.bredd = bredd;
    }

    /**
     * Hämtar ut bokens författare.
     * @return En sträng som innehåller bokens författare (eller
     * åtminstonne dess namn..).
     */
    public String getSkribent()
    {
        return skribent;
    }

    /**
     * Hämtar ut bokens titel.
     * @return En sträng som innehåller bokens titel.
     */
    public String getTitel()
    {
        return titel;
    }

    /**
     * Hämtar ut bokens bredd.
     * @return Bokens bredd i cm.
     */
    public int getBredd()
    {
        return bredd;
    }

    /**
     * Jämför två böcker. Bredast bok vinner.
     * @param b Boken att jämföra med
     * @return Negativt värde om boken är smalare än b, 0 om de är
     * lika breda och positivt värde om boken är bredare än b.
     */
    public int compareTo(Bok b)
    {
        return getBredd() - b.getBredd();
    }

    /**
     * Skapar en strängrepresentation av boken.
     * @return En strängrepresentation av boken.
     */
    public String toString()
    {
        return getTitel();
    }
}