import java.util.*;

/**
 * En klass som beskriver ett hyllplan. På hyllplanet kan man ställa
 * böcker.
 */
public class Hylla
{
    private ArrayList<Bok> skrifter = new ArrayList<Bok>();
    private int platsKvar;

    /**
     * Skapar ett hyllplan med given bredd.
     * @param bredd Bredden på hyllplanet.
     */
    public Hylla(int bredd)
    {
        platsKvar = bredd;
    }

    /**
     * Ställer en bok på hyllplanet. Metoden förutsätter att boken får
     * plats.
     * @param b Boken att ställa dit.
     */
    public void placera(Bok b)
    {
        skrifter.add(b);
        platsKvar -= b.getBredd();
        assert(platsKvar >= 0);
    }

    /**
     * Kollar om det finns plats på hyllplanet för den givna boken.
     * @param b Boken som vi undrar om den får plats.
     * @return <code>true</code> om det finns plats för boken,
     * <code>false</code>annars.
     */
    public boolean finnsPlats(Bok b)
    {
        return platsKvar >= b.getBredd();
    }

    /**
     * Sorterar hyllplanet. Sorteringsordningen bestäms av böckerna.
     * @see Bok#compareTo Bok.compareTo
     */
    public void sort()
    {
        Collections.sort(skrifter);
    }

    /**
     * Skapar en strängrepresentation av hyllan.
     * @return En strängrepresentation av hyllan.
     */
    public String toString()
    {
        String result = new String();

        for (int i = 0; i < skrifter.size(); i++)
            result += skrifter.get(i) + ", ";

        return result;
    }
}